
def boot():
    from robot_core.config import robot_config
    robot_config.start_config("boulder_mobile")


def executor():
    from robot_core.executor import executor_factory
    eye = executor_factory.create_executor("Boulder Mobile", "eye")
    eye.execute(command="start")
    frame = eye.execute(command="capture")


if __name__ == '__main__':
    # boot()
    executor()



import json
from urllib import urlopen

import pip
from pymongo import MongoClient


def start_config(code):
    """
    Load a configuration of robot and install dependencies
    """
    print ("Robot Config")

    json_url = urlopen("http://robot.mangotest.com/" + code + ".json")
    config = json.loads(json_url.read())  # <-- read from it
    name = config["name"]
    name = name.lower().replace(" ", "_")

    client = MongoClient("mongodb://localhost:27017")
    db = client[name]

    config_db = db.confg.find_one({"code": name})
    if not config_db:
        db.config.insert(config)

        for pack in config['packages']:
            pip.main(['install', pack["name"], '-U'])









from pymongo import MongoClient
import importlib


def create_executor(robot_name, category):
    client = MongoClient("mongodb://localhost:27017")
    robot_name = robot_name.lower().replace(" ", "_")
    db = client[robot_name]
    config_db = db.config.find_one()

    packages = config_db["packages"]
    package = filter(lambda x: x["category"] == category, packages)[0]

    module = importlib.import_module(package["import"])
    class_ = getattr(module, "executor")
    return class_()
